@@ -4,13 +4,14 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <QtTest>
+#include <QTest>
 
 #include "../settings_core.h"
 #include "core/document.h"
 #include <QMap>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QTemporaryFile>
 #include <core/form.h>
 #include <core/page.h>
 
