@@ -161,7 +161,7 @@ public:
     Generator *loadGeneratorLibrary(const KPluginMetaData &service);
     void loadAllGeneratorLibraries();
     void loadServiceList(const QList<KPluginMetaData> &offers);
-    void unloadGenerator(const GeneratorInfo &info);
+    void unloadGenerator(GeneratorInfo &info);
     void cacheExportFormats();
     void setRotationInternal(int r, bool notify);
     ConfigInterface *generatorConfig(GeneratorInfo &info);
@@ -196,9 +196,11 @@ public:
     void slotGeneratorConfigChanged();
     void refreshPixmaps(int);
     void _o_configChanged();
-    void doContinueDirectionMatchSearch(void *doContinueDirectionMatchSearchStruct);
-    void doContinueAllDocumentSearch(void *pagesToNotifySet, void *pageMatchesMap, int currentPage, int searchID);
-    void doContinueGooglesDocumentSearch(void *pagesToNotifySet, void *pageMatchesMap, int currentPage, int searchID, const QStringList &words);
+
+    typedef std::pair<RegularAreaRect *, QColor> MatchColor;
+    void doContinueDirectionMatchSearch(DoContinueDirectionMatchSearchStruct *searchStruct);
+    void doContinueAllDocumentSearch(QSet<int> *pagesToNotify, QHash<Page *, QList<RegularAreaRect *>> *pageMatches, int currentPage, int searchID);
+    void doContinueGooglesDocumentSearch(QSet<int> *pagesToNotify, QHash<Page *, QList<MatchColor>> *pageMatches, int currentPage, int searchID, const QStringList &words);
 
     void doProcessSearchMatch(RegularAreaRect *match, RunningSearch *search, QSet<int> *pagesToNotify, int currentPage, int searchID, bool moveViewport, const QColor &color);
 
@@ -276,6 +278,7 @@ public:
 
     // observers / requests / allocator stuff
     QSet<DocumentObserver *> m_observers;
+    // sorted by priority from lowest priority (highest number) at the head of the list to the highest priority (zero number) toward the end
     std::list<PixmapRequest *> m_pixmapRequestsStack;
     std::list<PixmapRequest *> m_executingPixmapRequests;
     QMutex m_pixmapRequestsMutex;
