@@ -442,6 +442,11 @@ void Generator::walletDataForFile(const QString &fileName, QString *walletName,
     *walletKey = fileName.section(QLatin1Char('/'), -1, -1);
     *walletName = KWallet::Wallet::NetworkWallet();
     *walletFolder = QStringLiteral("KPdf");
+#else
+    Q_UNUSED(fileName);
+    Q_UNUSED(walletName);
+    Q_UNUSED(walletFolder);
+    Q_UNUSED(walletKey);
 #endif
 }
 
@@ -782,7 +787,7 @@ ExportFormat ExportFormat::standardFormat(StandardExportFormat type)
     QMimeDatabase db;
     switch (type) {
     case PlainText:
-        return ExportFormat(QIcon::fromTheme(QStringLiteral("text-x-generic")), i18n("Plain &Text..."), db.mimeTypeForName(QStringLiteral("text/plain")));
+        return ExportFormat(QIcon::fromTheme(QStringLiteral("text-x-generic")), i18n("Plain &Text…"), db.mimeTypeForName(QStringLiteral("text/plain")));
         break;
     case PDF:
         return ExportFormat(QIcon::fromTheme(QStringLiteral("application-pdf")), i18n("PDF"), db.mimeTypeForName(QStringLiteral("application/pdf")));
