@@ -163,12 +163,12 @@ void dviRenderer::drawPage(RenderedDocumentPagePixmap *page)
     // Postprocess hyperlinks
     // Without that, based on the way TeX draws certain characters like german "Umlaute",
     // some hyperlinks would be broken into two overlapping parts, in the middle of a word.
-    QVector<Hyperlink>::iterator i = page->hyperLinkList.begin();
-    QVector<Hyperlink>::iterator j;
+    QList<Hyperlink>::iterator i = page->hyperLinkList.begin();
+    QList<Hyperlink>::iterator j;
     while (i != page->hyperLinkList.end()) {
         // Iterator j always points to the element after i.
         j = i;
-        j++;
+        ++j;
 
         if (j == page->hyperLinkList.end()) {
             break;
@@ -184,7 +184,7 @@ void dviRenderer::drawPage(RenderedDocumentPagePixmap *page)
             merged = true;
             hi.box = hi.box.united(hj.box);
 
-            j++;
+            ++j;
             if (j == page->hyperLinkList.end()) {
                 break;
             }
@@ -195,7 +195,7 @@ void dviRenderer::drawPage(RenderedDocumentPagePixmap *page)
         if (merged) {
             i = page->hyperLinkList.erase(++i, j);
         } else {
-            i++;
+            ++i;
         }
     }
 
@@ -223,7 +223,7 @@ void dviRenderer::getText(RenderedDocumentPagePixmap *page)
 void dviRenderer::showThatSourceInformationIsPresent()
 {
   // In principle, we should use a KMessagebox here, but we want to
-  // add a button "Explain in more detail..." which opens the
+  // add a button "Explain in more detail…" which opens the
   // Helpcenter. Thus, we practically re-implement the KMessagebox
   // here. Most of the code is stolen from there.
 
@@ -261,7 +261,7 @@ void dviRenderer::showThatSourceInformationIsPresent()
     QCheckBox *checkbox = new QCheckBox(i18n("Do not show this message again"), topcontents);
     topcontentsVBoxLayout->addWidget(checkbox);
     extraSize = QSize(50,0);
-    dialog.setHelpLinkText(i18n("Explain in more detail..."));
+    dialog.setHelpLinkText(i18n("Explain in more detail…"));
     dialog.setHelp("inverse-search", "kdvi");
     dialog.enableLinkedHelp(true);
     dialog.setMainWidget(topcontents);
@@ -586,8 +586,8 @@ Anchor dviRenderer::parseReference(const QString &reference)
         // document.
         bool anchorForRefFileFound = false; // Flag that is set if source file anchors for the refFileName could be found at all
 
-        QVector<DVI_SourceFileAnchor>::iterator bestMatch = sourceHyperLinkAnchors.end();
-        QVector<DVI_SourceFileAnchor>::iterator it;
+        QList<DVI_SourceFileAnchor>::iterator bestMatch = sourceHyperLinkAnchors.end();
+        QList<DVI_SourceFileAnchor>::iterator it;
         for (it = sourceHyperLinkAnchors.begin(); it != sourceHyperLinkAnchors.end(); ++it) {
             if (refFileName.trimmed() == it->fileName.trimmed() || refFileName.trimmed() == it->fileName.trimmed() + QStringLiteral(".tex")) {
                 anchorForRefFileFound = true;
