@@ -43,7 +43,7 @@ pagenode::pagenode()
         int t;                                                                                                                                                                                                                                 \
         NeedBits(wid);                                                                                                                                                                                                                         \
         TabEnt = tab + GetBits(wid);                                                                                                                                                                                                           \
-        printf("%08lX/%d: %s%5d\t", BitAcc, BitsAvail, StateNames[TabEnt->State], TabEnt->Param);                                                                                                                                              \
+        printf("%08u4/%d: %s%5d\t", BitAcc, BitsAvail, StateNames[TabEnt->State], TabEnt->Param);                                                                                                                                              \
         for (t = 0; t < TabEnt->Width; t++)                                                                                                                                                                                                    \
             DEBUG_SHOW;                                                                                                                                                                                                                        \
         putchar('\n');                                                                                                                                                                                                                         \
@@ -358,10 +358,10 @@ void MHexpand(pagenode *pn, drawfunc df)
     BitAcc = 0;
     BitsAvail = 0;
     lastx = pn->size.width();
-    runs = (pixnum *)malloc(lastx * sizeof(pixnum));
+    runs = static_cast<pixnum *>(malloc(lastx * sizeof(pixnum)));
     for (LineNum = 0; LineNum < pn->rowsperstrip;) {
 #ifdef DEBUG_FAX
-        printf("\nBitAcc=%08lX, BitsAvail = %d\n", BitAcc, BitsAvail);
+        printf("\nBitAcc=%08u, BitsAvail = %d\n", BitAcc, BitsAvail);
         printf("-------------------- %d\n", LineNum);
         fflush(stdout);
 #endif
@@ -415,11 +415,11 @@ void g31expand(pagenode *pn, drawfunc df)
     BitAcc = 0;
     BitsAvail = 0;
     lastx = pn->size.width();
-    runs = (pixnum *)malloc(lastx * sizeof(pixnum));
+    runs = static_cast<pixnum *>(malloc(lastx * sizeof(pixnum)));
     EOLcnt = 0;
     for (LineNum = 0; LineNum < pn->rowsperstrip;) {
 #ifdef DEBUG_FAX
-        fprintf(stderr, "\nBitAcc=%08lX, BitsAvail = %d\n", BitAcc, BitsAvail);
+        fprintf(stderr, "\nBitAcc=%08u, BitsAvail = %d\n", BitAcc, BitsAvail);
         fprintf(stderr, "-------------------- %d\n", LineNum);
         fflush(stderr);
 #endif
@@ -508,14 +508,14 @@ void g32expand(pagenode *pn, drawfunc df)
     BitAcc = 0;
     BitsAvail = 0;
     /* allocate space for 2 runlength arrays */
-    run0 = (pixnum *)malloc(2 * ((lastx + 5) & ~1) * sizeof(pixnum));
+    run0 = static_cast<pixnum *>(malloc(2 * ((lastx + 5) & ~1) * sizeof(pixnum)));
     run1 = run0 + ((lastx + 5) & ~1);
     run1[0] = lastx;
     run1[1] = 0;
     EOLcnt = 0;
     for (LineNum = 0; LineNum < pn->rowsperstrip;) {
 #ifdef DEBUG_FAX
-        printf("\nBitAcc=%08lX, BitsAvail = %d\n", BitAcc, BitsAvail);
+        printf("\nBitAcc=%08u, BitsAvail = %d\n", BitAcc, BitsAvail);
         printf("-------------------- %d\n", LineNum);
         fflush(stdout);
 #endif
@@ -635,14 +635,14 @@ void g4expand(pagenode *pn, drawfunc df)
     BitAcc = 0;
     BitsAvail = 0;
     /* allocate space for 2 runlength arrays */
-    run0 = (pixnum *)malloc(2 * ((lastx + 5) & ~1) * sizeof(pixnum));
+    run0 = static_cast<pixnum *>(malloc(2 * ((lastx + 5) & ~1) * sizeof(pixnum)));
     run1 = run0 + ((lastx + 5) & ~1);
     run1[0] = lastx; /* initial reference line */
     run1[1] = 0;
 
     for (LineNum = 0; LineNum < pn->rowsperstrip;) {
 #ifdef DEBUG_FAX
-        printf("\nBitAcc=%08lX, BitsAvail = %d\n", BitAcc, BitsAvail);
+        printf("\nBitAcc=%08u, BitsAvail = %d\n", BitAcc, BitsAvail);
         printf("-------------------- %d\n", LineNum);
         fflush(stdout);
 #endif
@@ -712,11 +712,11 @@ static const unsigned char zerotab[256] = {0x88, 0x07, 0x16, 0x06, 0x25, 0x05, 0
 int G3count(pagenode *pn, int twoD)
 {
     t16bits *p = pn->data;
-    t16bits *end = p + pn->length / sizeof(*p); // NOLINT(bugprone-sizeof-expression)
-    int lines = 0;                              /* lines seen so far */
-    int zeros = 0;                              /* number of consecutive zero bits seen */
-    int EOLcnt = 0;                             /* number of consecutive EOLs seen */
-    int empty = 1;                              /* empty line */
+    const t16bits *end = p + pn->length / sizeof(*p); // NOLINT(bugprone-sizeof-expression)
+    int lines = 0;                                    /* lines seen so far */
+    int zeros = 0;                                    /* number of consecutive zero bits seen */
+    int EOLcnt = 0;                                   /* number of consecutive EOLs seen */
+    int empty = 1;                                    /* empty line */
     int prezeros, postzeros;
 
     while (p < end && EOLcnt < 6) {
