@@ -8,7 +8,6 @@
 
 #include <KLocalizedString>
 
-#include <QDomDocument>
 #include <QTextCursor>
 #include <QTextDocument>
 #include <QTextFrame>
@@ -29,35 +28,12 @@ extern "C" {
 
 using namespace Markdown;
 
-static void recursiveRenameTags(QDomElement &elem)
-{
-    for (QDomNode node = elem.firstChild(); !node.isNull(); node = node.nextSibling()) {
-        QDomElement child = node.toElement();
-        if (!child.isNull()) {
-            // Discount emits <del> tags for ~~ but Qt doesn't understand them and
-            // removes them. Instead replace them with <s> tags which Qt does
-            // understand.
-            if (child.nodeName() == QStringLiteral("del")) {
-                child.setTagName(QStringLiteral("s"));
-            }
-            recursiveRenameTags(child);
-        }
-    }
-}
-
 QString detail::fixupHtmlTags(QString &&html)
 {
-    QDomDocument dom;
-    // Discount emits simplified HTML but QDomDocument will barf if everything isn't
-    // inside a "root" node. Luckily QTextDocument ignores unknown tags so we can just
-    // wrap the original HTML with a fake tag that'll be stripped off later.
-    if (!dom.setContent(QStringLiteral("<ignored_by_qt>") + html + QStringLiteral("</ignored_by_qt>"))) {
-        return std::move(html);
-    }
-    QDomElement elem = dom.documentElement();
-    recursiveRenameTags(elem);
-    // Don't add any indentation otherwise code blocks can gain indents.
-    return dom.toString(-1);
+    // Discount emits <del> tags for ~~ but Qt doesn't understand them and
+    // removes them. Instead replace them with <s> tags which Qt does
+    // understand.
+    return html.replace(QStringLiteral("<del>"), QStringLiteral("<s>")).replace(QStringLiteral("</del>"), QStringLiteral("</s>"));
 }
 
 Converter::Converter()
