@@ -8,15 +8,22 @@
 #include <QFile>
 #include <QRegularExpression>
 #include <qmobipocket/mobipocket.h>
-#include <qmobipocket/qfilestream.h>
 
 using namespace Mobi;
 
 MobiDocument::MobiDocument(const QString &fileName)
     : QTextDocument()
+#if QMOBIPOCKET_VERSION_MAJOR < 3
+    , m_file(Mobipocket::QFileStream(fileName))
 {
-    file = new Mobipocket::QFileStream(fileName);
-    doc = new Mobipocket::Document(file);
+#else
+    , m_file(QFile(fileName))
+{
+    if (!m_file.open(QIODeviceBase::ReadOnly)) {
+        return;
+    }
+#endif
+    doc = std::make_unique<Mobipocket::Document>(&m_file);
     if (doc->isValid()) {
         QString text = doc->text();
         QString header = text.left(1024);
@@ -29,11 +36,7 @@ MobiDocument::MobiDocument(const QString &fileName)
     }
 }
 
-MobiDocument::~MobiDocument()
-{
-    delete doc;
-    delete file;
-}
+MobiDocument::~MobiDocument() = default;
 
 QVariant MobiDocument::loadResource(int type, const QUrl &name)
 {
