@@ -50,7 +50,7 @@
 class PickPointEngine : public AnnotatorEngine
 {
 public:
-    explicit PickPointEngine(const QDomElement &engineElement)
+    explicit PickPointEngine(PageView *pageView, const QDomElement &engineElement)
         : AnnotatorEngine(engineElement)
         , clicked(false)
         , xscale(1.0)
@@ -59,6 +59,7 @@ public:
         , iconName {m_annotElement.attribute(QStringLiteral("icon"))}
         , pagewidth(1.0)
         , pageheight(1.0)
+        , pageView(pageView)
     {
         // parse engine specific attributes
         if (m_annotElement.attribute(QStringLiteral("type")) == QLatin1String("Stamp") && !iconName.simplified().isEmpty()) {
@@ -135,13 +136,54 @@ public:
     {
         if (clicked) {
             if (m_block) {
-                const QPen origpen = painter->pen();
-                QPen pen = painter->pen();
-                pen.setStyle(Qt::DashLine);
-                painter->setPen(pen);
                 const Okular::NormalizedRect tmprect(qMin(startpoint.x, point.x), qMin(startpoint.y, point.y), qMax(startpoint.x, point.x), qMax(startpoint.y, point.y));
                 const QRect realrect = tmprect.geometry((int)xScale, (int)yScale);
-                painter->drawRect(realrect);
+                const QPen origpen = painter->pen();
+                QPen pen = painter->pen();
+                // Draw rectangle in 3 colored dashed line
+                const QColor baseColor = QApplication::palette().base().color();
+                const QColor textColor = QApplication::palette().text().color();
+                const QColor highlightColor = QApplication::palette().highlight().color();
+                const qreal penWidth = pen.widthF();
+                pen.setDashPattern({penWidth * 5, penWidth * 10} /* { dash, empty space } */);
+                pen.setColor(baseColor);
+                painter->setPen(pen);
+                // Use drawLine instead of drawRect to avoid shimering on resize
+                painter->drawLine(realrect.topLeft(), realrect.topRight());
+                painter->drawLine(realrect.topLeft(), realrect.bottomLeft());
+                painter->drawLine(realrect.topRight(), realrect.bottomRight());
+                painter->drawLine(realrect.bottomLeft(), realrect.bottomRight());
+
+                pen.setDashOffset(penWidth * 5);
+                pen.setColor(textColor);
+                painter->setPen(pen);
+                painter->drawLine(realrect.topLeft(), realrect.topRight());
+                painter->drawLine(realrect.topLeft(), realrect.bottomLeft());
+                painter->drawLine(realrect.topRight(), realrect.bottomRight());
+                painter->drawLine(realrect.bottomLeft(), realrect.bottomRight());
+
+                pen.setDashOffset(penWidth * 10);
+                pen.setColor(highlightColor);
+                painter->setPen(pen);
+                painter->drawLine(realrect.topLeft(), realrect.topRight());
+                painter->drawLine(realrect.topLeft(), realrect.bottomLeft());
+                painter->drawLine(realrect.topRight(), realrect.bottomRight());
+                painter->drawLine(realrect.bottomLeft(), realrect.bottomRight());
+
+                // and draw the internal 3x3 grid
+                pen.setStyle(Qt::DashLine);
+                pen.setColor(highlightColor);
+                painter->setPen(pen);
+                const QPoint rectTopLeft = realrect.topLeft();
+                const QPoint rectBottomRight = realrect.bottomRight();
+                const int yHorizontal1 = rectTopLeft.y() + (realrect.height() + 2) / 3;
+                const int yHorizontal2 = rectTopLeft.y() + (realrect.height() + 2) / 3 * 2;
+                painter->drawLine(rectTopLeft.x(), yHorizontal1, rectBottomRight.x(), yHorizontal1);
+                painter->drawLine(rectTopLeft.x(), yHorizontal2, rectBottomRight.x(), yHorizontal2);
+                const int xVertical1 = rectTopLeft.x() + (realrect.width() + 2) / 3;
+                const int xVertical2 = rectTopLeft.x() + (realrect.width() + 2) / 3 * 2;
+                painter->drawLine(xVertical1, rectTopLeft.y(), xVertical1, rectBottomRight.y());
+                painter->drawLine(xVertical2, rectTopLeft.y(), xVertical2, rectBottomRight.y());
                 painter->setPen(origpen);
             }
             if (!pixmap.isNull()) {
@@ -217,7 +259,7 @@ public:
             addInPlaceTextAnnotation(ann, i18n("Inline Note"), QString(), Okular::TextAnnotation::Unknown);
         } else if (typeString == QLatin1String("Typewriter")) {
             bool resok;
-            const QString content = QInputDialog::getMultiLineText(nullptr, i18n("New Text Note"), i18n("Text of the new note:"), QString(), &resok);
+            const QString content = QInputDialog::getMultiLineText(pageView, i18n("New Text Note"), i18n("Text of the new note:"), QString(), &resok);
             if (resok) {
                 addInPlaceTextAnnotation(ann, i18n("Typewriter"), content, Okular::TextAnnotation::TypeWriter);
             }
@@ -327,6 +369,7 @@ private:
     int size;
     double pagewidth, pageheight;
     bool center;
+    PageView *pageView = nullptr;
 };
 
 class PickPointEngineSignature : public PickPointEngine
@@ -334,7 +377,7 @@ class PickPointEngineSignature : public PickPointEngine
 #if HAVE_NEW_SIGNATURE_API
 public:
     explicit PickPointEngineSignature(SignaturePartUtils::SigningInformation *info)
-        : PickPointEngine({})
+        : PickPointEngine(nullptr, {})
         , m_page(nullptr)
         , m_aborted(false)
         , m_signingInformation(info)
@@ -414,7 +457,7 @@ private:
 #else
 public:
     PickPointEngineSignature(Okular::Document *document, PageView *pageView, SignaturePartUtils::SigningInformation *info)
-        : PickPointEngine({})
+        : PickPointEngine(pageView, {})
         , m_document(document)
         , m_page(nullptr)
         , m_pageView(pageView)
@@ -1283,7 +1326,7 @@ void PageViewAnnotator::selectTool(AnnotationTools *toolsDefinition, int toolId,
         // ask the user for confirmation/change
         if (userName.isEmpty()) {
             bool ok = false;
-            userName = QInputDialog::getText(nullptr, i18n("Author name"), i18n("Author name for the annotation:"), QLineEdit::Normal, QString(), &ok);
+            userName = QInputDialog::getText(m_pageView, i18n("Author name"), i18n("Author name for the annotation:"), QLineEdit::Normal, QString(), &ok);
 
             if (!ok) {
                 detachAnnotation();
@@ -1329,7 +1372,7 @@ void PageViewAnnotator::selectTool(AnnotationTools *toolsDefinition, int toolId,
             if (type == QLatin1String("SmoothLine")) {
                 m_engine = new SmoothPathEngine(engineElement);
             } else if (type == QLatin1String("PickPoint")) {
-                m_engine = new PickPointEngine(engineElement);
+                m_engine = new PickPointEngine(m_pageView, engineElement);
             } else if (type == QLatin1String("PolyLine")) {
                 m_engine = new PolyLineEngine(engineElement);
             } else if (type == QLatin1String("TextSelector")) {
@@ -1724,7 +1767,7 @@ void PageViewAnnotator::addToQuickAnnotations()
 
     // set custom name for quick annotation
     bool ok = false;
-    QString itemText = QInputDialog::getText(nullptr, i18n("Add favorite annotation"), i18n("Custom annotation name:"), QLineEdit::Normal, defaultToolName(sourceToolElement), &ok);
+    QString itemText = QInputDialog::getText(m_pageView, i18n("Add favorite annotation"), i18n("Custom annotation name:"), QLineEdit::Normal, defaultToolName(sourceToolElement), &ok);
     if (!ok) {
         return;
     }
