@@ -28,7 +28,7 @@ class PreferencesDialog : public KConfigDialog
     Q_OBJECT
 
 public:
-    PreferencesDialog(QWidget *parent, KConfigSkeleton *skeleton, Okular::EmbedMode embedMode);
+    PreferencesDialog(QWidget *parent, KConfigSkeleton *skeleton, Okular::EmbedMode embedMode, const QString &editCmd);
 
     void switchToAccessibilityPage();
     void switchToAnnotationsPage();
